package beilv.session.service;


import beilv.session.domain.BeilvSession;

import java.util.List;

/**
 * 时段管理Service接口
 * 
 * @author lc
 * @date 2025-01-06
 */
public interface IBeilvSessionService 
{
    /**
     * 查询时段管理
     * 
     * @param id 时段管理主键
     * @return 时段管理
     */
    public BeilvSession selectBeilvSessionById(Long id);

    /**
     * 查询时段管理列表
     * 
     * @param beilvSession 时段管理
     * @return 时段管理集合
     */
    public List<BeilvSession> selectBeilvSessionList(BeilvSession beilvSession);

    /**
     * 新增时段管理
     * 
     * @param beilvSession 时段管理
     * @return 结果
     */
    public int insertBeilvSession(BeilvSession beilvSession);

    /**
     * 修改时段管理
     * 
     * @param beilvSession 时段管理
     * @return 结果
     */
    public int updateBeilvSession(BeilvSession beilvSession);

    /**
     * 批量删除时段管理
     * 
     * @param ids 需要删除的时段管理主键集合
     * @return 结果
     */
    public int deleteBeilvSessionByIds(String ids);

    /**
     * 删除时段管理信息
     * 
     * @param id 时段管理主键
     * @return 结果
     */
    public int deleteBeilvSessionById(Long id);

    List<BeilvSession> getAllToList();
}
